@@ -27,7 +27,7 @@ sub init {
     my $elem;
     unless ($elem = $param{Elem}) {
         if (LIBXML) {
-            my $doc = XML::LibXML::Document->createDocument('1.0', 'utf-8');
+            my $doc = XML::LibXML::Document->createDocument('1.0', 'UTF-8');
             my $ns = $obj->ns;
             my ($ns_uri, $ns_prefix);
             if ( ref $ns and $ns->isa('XML::Atom::Namespace') ) {
@@ -84,7 +84,7 @@ sub getlist {
     my $obj = shift;
     my($ns, $name) = @_;
     my $ns_uri = ref($ns) eq 'XML::Atom::Namespace' ? $ns->{uri} : $ns;
-    my @node = nodelist($obj->elem, $ns_uri, $name);
+    my @node = childlist($obj->elem, $ns_uri, $name);
     return map {
         my $val = LIBXML ? $_->textContent : $_->string_value;
         if ($] >= 5.008) {
@@ -127,6 +127,8 @@ sub set {
                 $elem->appendAttribute($attr);
             }
         }
+    } elsif (DATETIME && UNIVERSAL::isa($val, "DateTime")) {
+        return $obj->set($ns, $name, DateTime::Format::Atom->format_datetime($val), $attr, $add);
     } else {
         if (LIBXML) {
             $elem->appendChild(XML::LibXML::Text->new($val));
@@ -351,11 +353,11 @@ sub mk_object_list_accessor {
 sub as_xml {
     my $obj = shift;
     if (LIBXML) {
-        my $doc = XML::LibXML::Document->new('1.0', 'utf-8');
+        my $doc = XML::LibXML::Document->new('1.0', 'UTF-8');
         $doc->setDocumentElement($obj->elem->cloneNode(1));
         return $doc->toString(1);
     } else {
-        return '<?xml version="1.0" encoding="utf-8"?>' . "\n" .
+        return '<?xml version="1.0" encoding="UTF-8"?>' . "\n" .
             $obj->elem->toString;
     }
 }
